/* @(#) $Id: XmlDSigToolFormUtil.js,v 1.1 2008/04/22 20:08:43 subrata Exp $ */

/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is  Avaya Labs Research, Avaya Inc. Code.
 *
 * The Initial Developer of the Original Code is
 *     Subrata Mazumdar, Subrata Mazumdar, Avaya Labs Research, Avaya Inc.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Subrata Mazumdar (mazum@avaya.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


// const PERMS_FILE      = 0644;
const PERMS_DIRECTORY = 0755;

function xmldsigffext_autoSelectOutFile(aFilePickerElem, aFileName)
{
    var outFile = null;
    try {
    	var tmpDirFile = aFilePickerElem.fileDisplayDirFile;
        if (!tmpDirFile) {
    	    tmpDirFile = aFilePickerElem.getTmpDir("XMLDSigTool");
        }
    	if (!tmpDirFile.exists()) {
	    tmpDirFile.create(Components.interfaces.nsILocalFile.DIRECTORY_TYPE, PERMS_DIRECTORY);
    	}
    	outFile = aFilePickerElem.autoSelectFile(tmpDirFile, aFileName);
    	if (outFile == null) {
    	    dump("xmldsigffext_autoSelectOutFile(): failed to get outFile.\n");
            return outFile;
    	}
    } catch (ex) {
    	dump("xmldsigffext_autoSelectOutFile(): failed to create outFile - ex : " + ex + "\n");
	throw ex;
    }
    // dump("xmldsigffext_autoSelectOutFile(): outFile: " + outFile.path + "\n");
    return outFile;
}

function xmldsigffext_loginToCertToken(aCert, force)
{
    var tokendb = Components.classes["@mozilla.org/security/pk11tokendb;1"]
    			.getService(Components.interfaces.nsIPK11TokenDB);
    var keyTokenName = "" + aCert.tokenName;
    var /* nsIPK11Token */ token = tokendb.findTokenByName(keyTokenName);
    if (token == null) {
        return;
    }
    var forceLogin = ((force == null) ? false : force);
    token.login(forceLogin);
}

/* nsIPersistentProperties */
function getSignatureFormProperties(tabPanelId)
{
    netscape.security.PrivilegeManager.enablePrivilege('UniversalXPConnect');
    var xmlSigProps = Components.classes["@mozilla.org/persistent-properties;1"].
                    createInstance(Components.interfaces.nsIPersistentProperties);

    var propKey;
    var propValue;
    var propOldValue;
    var trueValue = "true";

    // dump("getSignatureFormProperties(): tabPanelId: " + tabPanelId + "\n");

    var gXmlSignFormElem = document.getElementById(tabPanelId);
    var /* NodeList */ xmlSignFormPropElemList = gXmlSignFormElem.getElementsByAttribute("sigParamName", "*");
    // xmlSignFormPropElemList = gXmlSignFormElem.getElementsByAttribute("id", "*");
    for (var i = 0; i < xmlSignFormPropElemList.length; i++) {
	var xmlSigPropElem = xmlSignFormPropElemList.item(i);
	// dump("i: " + i + " tagName: " + xmlSigPropElem.tagName + " id: " + xmlSigPropElem.id + "\n");

	if (xmlSigPropElem.hidden) {
	    continue;
	}
	var propKey = xmlSigPropElem.getAttribute("sigParamName");
	if ((propKey == null) || (propKey == "")) {
	    continue;
	}
	propValue = "";
	if (xmlSigPropElem.tagName == "checkbox") {
	    if (xmlSigPropElem.checked) {
	    	propValue = trueValue;
	    }
	}
	else if (xmlSigPropElem.tagName == "radiogroup") {
	    propValue = xmlSigPropElem.selectedItem.value;
	}
	else if (xmlSigPropElem.tagName == "radio") {
	    if (xmlSigPropElem.selected) {
	    	// propValue = xmlSigPropElem.value;
	    	propValue = xmlSigPropElem.value;
	    }
	}
	else if (xmlSigPropElem.value) {
	    propValue = xmlSigPropElem.value;
	}
	else {
	    var tmpVal = xmlSigPropElem.getAttribute("value");
	    if (tmpVal) {
	        propValue = tmpVal;
	    }
	}
	if (propValue != "") {
	    propOldValue = xmlSigProps.setStringProperty(propKey, propValue);
	}
	// dump("id: " + xmlSigPropElem.id + " propKey: " + propKey + " = " + propValue + "\n");
    }
    // dumpProperties(xmlSigProps, "xmlSignatureParams:");
    return xmlSigProps;
}


function dumpProperties(/* nsIPersistentProperties */ aProps, msg)
{
    var propKey;
    var propValue;
    var propOldValue;

    if (msg) {
        dump(msg + " ");
    }
    dump(" Properties {\n");
    var propEnum = aProps.enumerate();
    while (propEnum.hasMoreElements ()) {
        var propElem = propEnum.getNext ();
        var propItem = propElem.QueryInterface (Components.interfaces.nsIPropertyElement);
        var propKey = propItem.key;
        var propValue = propItem.value;
        dump("    " + propKey + " = " + propValue + "\n");
    }
    dump("}\n");
}

function trimString(aStr)
{
    // var newStr = (new java.lang.String(aStr)).trim();
    // return newStr;
    var sInString = aStr.replace( /^\s+/g, "" );// strip leading
    return sInString.replace( /\s+$/g, "" );// strip trailing
}

function xmldsigffext_isSupportedOS()
{
    var winNavigator = window.navigator;
    var userAgent = window.navigator.userAgent;

    /*
    var isWin = (userAgent.indexOf("Win") != -1);
    var isLinux = (userAgent.indexOf("Linux") != -1);
    // var isMac = (userAgent.indexOf("Mac") != -1);
    if (!(isWin || isLinux)) {
    	alert("ERROR: WRONG BROWSER USER AGENT (" + userAgent + ")\n" +
        	"This tool is only supported on Linux_x86-gcc3 and Windows_x86-msvc platforms.");
    	return false;
    }
    */

    dump("xmldsigffext_isSupportedOS(): userAgent: " + userAgent + "\n");
    /*
    if (window.navigator.onLine) {
	// Touch base - experimental
	var remoteURL = "http://www.research.avayalabs.com/gcm/usa/en-us/people/all/subratamazumdar.htm";
	var httpMethod = "HEAD";
	try {
	    var req = new XMLHttpRequest(); // Request
	    req.open(httpMethod, remoteURL, false);  // false ==> synchronous
	    req.send("");
	    dump("xmldsigffext_isSupportedOS(): HTTP HEAD - req.status: " + req.status + "\n");
	    if ((req.status / 100) != 2 ) {
	        dump("xmldsigffext_isSupportedOS(): HTTP HEAD failed - req.status: " + req.status + "\n");
	    }
	} catch (ex) {}
    }
    */
    
    return true;
}


